Overview — aeolus 0.4.9+9.g5a71939.dirty documentation

# Overview

aeolus is a Python library for the analysis and visualisation of climate model output, primarily the UK Met Office Unified Model. It leverages the functionality of iris and has modules geared towards working with 3D general circulation models of planetary atmospheres.

## Contents

- Installation
- Examples
- API reference
- Changelog
- Contributor’s Guide

## See also

- The iris package, upon which aeolus relies heavily.

- The repository with code used for the figures in Sergeev et al. (2020).

## License

Aeolus is released under the terms of the LGPL-3.0 license.

# Indices and tables

- Index

- Search Page